@@ -112,6 +112,7 @@ protected Q_SLOTS:
     void enableTypesetting(bool enable);
     void showBackendHelp();
     void print();
+    void printPreview();
 
     void worksheetStatusChanged(Cantor::Session::Status stauts);
     void showSessionError(const QString& error);
@@ -158,6 +159,7 @@ private:
     Cantor::PanelPluginHandler* m_panelHandler;
 
     QProgressDialog* m_initProgressDlg;
+    bool m_showProgressDlg;
     QAction * m_evaluate;
     QAction * m_save;
     QAction * m_findNext;
@@ -171,6 +173,9 @@ private:
 
     QString m_cachedStatusMessage;
     bool m_statusBarBlocked;
+
 };
 
+
+
 #endif // CANTORPART_H
